
from distutils.core import setup

setup(name='egen111222-cart_project',
      version='1.0',
      description='Корзина для магазину',
      author='Kirill',
      author_email='egen13@ukr.net',
      packages=['cart_project'],
     )



# Item
# Cart

class Item:
    """
    Товар для роботи магазину

    :param name: Назва товару
    :type name:str
    :param description: Опис товару
    :type description:str
    :param price: Ціна товару
    :type price:float
    """
    def __init__(self,
                 name:str,
                 description:str,
                 price:float):
        self.name = name
        self.description = description
        self.price = price

    def show(self):
        """
        Метод відображення інформації про товар
        """
        print(f"""Назва товару:{self.name}
Опис товару:{self.description}
Ціна товару:{self.price}""")




class Cart:
    """
    Корзина для магазину

    :param items: Товари у корзині
    :type items: list
    """
    def __init__(self):
        self.items = []
        
    def get_count(self):
        """
        Метод вираховує кількість товарів у корзині

        :return: Повертаємо кількість товарів
        :rtype:int
        """
        return len(self.items)
    
    def get_price(self):
        """
        Метод для підрахунку вартості товарів у корзині

        :return: Повертаємо вартість товарів
        :rtype:int|float
        """
        price = 0
        for item in self.items:
            price += item.price
        return price

